@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: yesod
 version: 1.4.2
-id: yesod-1.4.2-1b35010312ab419b61f60d2144436df2
-key: yesod_2WbcnXHQpNOIH4Oluk4mE4
+id: yesod-1.4.2-d6317c3095bd2c74629cf97c7fc2102e
+key: yesod_K2kbtomDZI5J4lsL4BSRUZ
 license: MIT
 maintainer: Michael Snoyman <michael@snoyman.com>
 stability: Stable
@@ -21,7 +21,7 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-1.4.2
 library-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-1.4.2
 data-dir: /usr/share/arm-linux-ghc-7.10.3/yesod-1.4.2
-hs-libraries: HSyesod-1.4.2-2WbcnXHQpNOIH4Oluk4mE4
+hs-libraries: HSyesod-1.4.2-K2kbtomDZI5J4lsL4BSRUZ
 depends:
     aeson-0.10.0.0-d37842f030fec47bc6e0ba2aef0f6571
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
@@ -48,7 +48,7 @@ depends:
     wai-logger-2.2.4.1-78754ae80b1823d94a638e54c94b2c6e
     warp-3.2.1-8f9aad771e0c137389da779f459b244d
     yaml-0.8.15.3-3d6bb92af78b0dac755a8e256ace903e
-    yesod-auth-1.4.12-1bd872bb0b3bb50f84405f03c3060b46
+    yesod-auth-1.4.12-8d535892f623fa948d936e886d3bdb4c
     yesod-core-1.4.19-516d05f0f7a24f16b48a3d78a1b5e378
     yesod-form-1.4.6-4e51451ad8a0ff5cee562f45fede6545
     yesod-persistent-1.4.0.3-e292066aa899804c642be44b1d89205f
